@@ -1089,6 +1089,10 @@ GtkWidget *xface_get_from_header(const gchar *o_xface)
 	static gchar *xpm_xface[XPM_XFACE_HEIGHT];
 	static gboolean xpm_xface_init = TRUE;
 	gchar xface[2048];
+	
+	if (o_xface == NULL)
+		return NULL;
+	
 	strncpy(xface, o_xface, sizeof(xface) - 1);
 	xface[sizeof(xface) - 1] = '\0';
 
@@ -1707,8 +1711,8 @@ claws_input_add    (gint	      source,
  *
  * @return a GdkPixbuf
  */
-GdkPixbuf *claws_load_pixbuf_fitting(GdkPixbuf *src_pixbuf, int box_width,
-				     int box_height)
+GdkPixbuf *claws_load_pixbuf_fitting(GdkPixbuf *src_pixbuf, gboolean inline_img,
+				     gboolean fit_img_height, int box_width, int box_height)
 {
 	gint w, h, orientation, angle;
 	gint avail_width, avail_height;
@@ -1779,9 +1783,20 @@ GdkPixbuf *claws_load_pixbuf_fitting(GdkPixbuf *src_pixbuf, int box_width,
 	avail_height = box_height;
 		
 	if (box_width != -1 && box_height != -1 && avail_width - 100 > 0) {
-		if (w > avail_width || h > avail_height) {
-			h = (avail_width * h) / w;
-			w = avail_width;
+		if (inline_img || fit_img_height) {
+			if (w > avail_width) {
+				h = (avail_width * h) / w;
+				w = avail_width;
+			}
+			if (h > avail_height) {
+				w = (avail_height * w) / h;
+				h = avail_height;
+			}
+		} else {
+			if (w > avail_width || h > avail_height) {
+				h = (avail_width * h) / w;
+				w = avail_width;
+			}
 		}
 		t_pixbuf = gdk_pixbuf_scale_simple(pixbuf, 
 			w, h, GDK_INTERP_BILINEAR);
