@@ -61,6 +61,7 @@
 #include "hooks.h"
 #include "logwindow.h"
 #include "passwordstore.h"
+#include "oauth2.h"
 
 extern SessionStats session_stats;
 
@@ -633,6 +634,10 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 				(inc_dialog->dialog->window,
 				 NULL, NULL);
 
+		if(pop3_session->ac_prefs->use_pop_auth && 
+		   pop3_session->ac_prefs->pop_auth_type == POPAUTH_OAUTH2)
+		     oauth2_check_passwds (pop3_session->ac_prefs);
+		
 		if (password_get(pop3_session->user,
 					pop3_session->ac_prefs->recv_server,
 					"pop3", pop3_get_port(pop3_session),
