@@ -41,9 +41,16 @@ typedef enum {
 	SIG_DIRECT
 } SigType;
 
+typedef enum
+{
+	POPAUTH_APOP      = 1 << 0,
+	POPAUTH_OAUTH2    = 1 << 1
+} POPAuthType;
+
 #include <glib.h>
 
 #include "smtp.h"
+#include "pop.h"
 #include "gtk/prefswindow.h"
 
 struct _Folder;
@@ -86,9 +93,12 @@ struct _PrefsAccount
 
 	gboolean ssl_certs_auto_accept;
 	gboolean use_nonblocking_ssl;
+	gboolean use_tls_sni;
 
 	/* Receive */
-	gboolean use_apop_auth;
+	gboolean use_pop_auth;
+        POPAuthType pop_auth_type;
+	gboolean use_apop_auth; /* deprecated */
 	gboolean rmmail;
 	gint msg_leave_time;
 	gint msg_leave_hour;
@@ -126,6 +136,13 @@ struct _PrefsAccount
 
 	GSList *customhdr_list;
 
+        /* OAuth2 */
+	gint oauth2_provider;
+	gint oauth2_date;
+	gchar *oauth2_authcode;
+	gchar *oauth2_client_id;
+	gchar *oauth2_client_secret;
+
 	/* Compose */
 	SigType sig_type;
 	gchar    *sig_path;
