@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2019 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2021 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 #include "prefs_msg_colors.h"
 #include "prefs_summary_open.h"
 
-#define CLAWS_CONFIG_VERSION 3
+#define CLAWS_CONFIG_VERSION 4
 
 typedef struct _PrefsCommon	PrefsCommon;
 
@@ -246,6 +246,7 @@ struct _PrefsCommon
 	gboolean display_img;
 	gboolean resize_img;
 	gboolean inline_img;
+	gboolean fit_img_height;
 
 	gboolean trans_hdr;
 	gint display_folder_unread;
@@ -354,6 +355,7 @@ struct _PrefsCommon
 	gboolean display_header_pane;
 	gboolean display_header;
 	gboolean display_xface;
+	gboolean save_xface;
 	gint line_space;
 	gboolean render_html;
 	gboolean invoke_plugin_on_html;
